github-actions-0.1.1.0: Github Actions
Copyright(c) 2025 Bellroy Pty Ltd
LicenseBSD-3-Clause
MaintainerBellroy Tech Team <haskell@bellroy.com>
Safe HaskellNone
LanguageHaskell2010

Language.Github.Actions.Concurrency

Description

This module provides the Concurrency type for controlling concurrent execution of GitHub Actions workflows and jobs.

Concurrency settings allow you to control how many workflow runs or job executions can happen simultaneously.

For more information about GitHub Actions concurrency, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#concurrency

Synopsis

Documentation

data Concurrency Source #

Concurrency settings for workflows and jobs.

Concurrency allows you to control whether multiple workflow runs or job executions can happen simultaneously. This is useful for preventing conflicts when deploying or when you want to ensure only one workflow processes a particular resource at a time.

Example usage:

import Language.Github.Actions.Concurrency

-- Only allow one deployment per branch
deploymentConcurrency :: Concurrency
deploymentConcurrency = Concurrency
 { group = Just "${{ github.ref }}"
 , cancelInProgress = Just True
 }

For more details, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#concurrency

Constructors

Concurrency 

Fields

Instances

Instances details
FromJSON Concurrency Source # 
Instance details

Defined in Language.Github.Actions.Concurrency

ToJSON Concurrency Source # 
Instance details

Defined in Language.Github.Actions.Concurrency

Generic Concurrency Source # 
Instance details

Defined in Language.Github.Actions.Concurrency

Associated Types

type Rep Concurrency 
Instance details

Defined in Language.Github.Actions.Concurrency

type Rep Concurrency = D1 ('MetaData "Concurrency" "Language.Github.Actions.Concurrency" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'False) (C1 ('MetaCons "Concurrency" 'PrefixI 'True) (S1 ('MetaSel ('Just "group") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "cancelInProgress") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Bool))))
Show Concurrency Source # 
Instance details

Defined in Language.Github.Actions.Concurrency

Eq Concurrency Source # 
Instance details

Defined in Language.Github.Actions.Concurrency

Ord Concurrency Source # 
Instance details

Defined in Language.Github.Actions.Concurrency

type Rep Concurrency Source # 
Instance details

Defined in Language.Github.Actions.Concurrency

type Rep Concurrency = D1 ('MetaData "Concurrency" "Language.Github.Actions.Concurrency" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'False) (C1 ('MetaCons "Concurrency" 'PrefixI 'True) (S1 ('MetaSel ('Just "group") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "cancelInProgress") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Bool))))