| Copyright | (c) 2025 Bellroy Pty Ltd |
|---|---|
| License | BSD-3-Clause |
| Maintainer | Bellroy Tech Team <haskell@bellroy.com> |
| Safe Haskell | None |
| Language | Haskell2010 |
Language.Github.Actions.Defaults
Description
This module provides the Defaults type for setting default values that apply
to all steps within a job or all jobs within a workflow.
Defaults allow you to specify common settings like shell type and working directory that will be inherited by all steps unless explicitly overridden at the step level.
For more information about GitHub Actions defaults, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#defaults
Documentation
Default settings for steps within a job or jobs within a workflow.
Defaults provide a convenient way to set common configuration that applies to both Jobs and Workflows without having to repeat the same settings everywhere.
Example usage:
import Language.Github.Actions.Defaults
import Language.Github.Actions.Shell
-- Set bash as default shell for all steps
bashDefaults :: Defaults
bashDefaults = Defaults
{ runShell = Just (Bash Nothing)
, runWorkingDirectory = Nothing
}
-- Set working directory for all steps
workdirDefaults :: Defaults
workdirDefaults = Defaults
{ runShell = Nothing
, runWorkingDirectory = Just "/src"
}
For more details, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#defaults
Constructors
| Defaults | |