github-actions-0.1.1.0: Github Actions
Copyright(c) 2025 Bellroy Pty Ltd
LicenseBSD-3-Clause
MaintainerBellroy Tech Team <haskell@bellroy.com>
Safe HaskellNone
LanguageHaskell2010

Language.Github.Actions.Service.Id

Description

This module provides the ServiceId type for uniquely identifying service containers within GitHub Actions jobs.

Service IDs are used to reference service containers from job steps via hostname. They must be unique within a job and follow specific naming conventions.

For more information about GitHub Actions service containers, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#jobsjob_idservices

Synopsis

Documentation

newtype ServiceId Source #

A unique identifier for a service container within a GitHub Actions job.

Service IDs are used to: * Reference the service container from job steps using the service ID as hostname * Configure service-specific settings like ports, environment variables, and health checks * Identify services in workflow run logs and container networks

Service IDs must be unique within a job and should follow these conventions: * Start with a letter or underscore * Contain only alphanumeric characters, hyphens, and underscores * Be descriptive of the service's purpose

Example usage:

import Language.Github.Actions.Service.Id

-- Database service IDs
postgresServiceId :: ServiceId
postgresServiceId = ServiceId "postgres"

redisServiceId :: ServiceId
redisServiceId = ServiceId "redis"

-- More descriptive service IDs
testDatabaseServiceId :: ServiceId
testDatabaseServiceId = ServiceId "test-database"

For more details, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#jobsjob_idservices

Constructors

ServiceId Text 

Instances

Instances details
FromJSON ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

FromJSONKey ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

ToJSON ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

ToJSONKey ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

Generic ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

Associated Types

type Rep ServiceId 
Instance details

Defined in Language.Github.Actions.Service.Id

type Rep ServiceId = D1 ('MetaData "ServiceId" "Language.Github.Actions.Service.Id" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'True) (C1 ('MetaCons "ServiceId" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)))
Show ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

Eq ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

Ord ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

type Rep ServiceId Source # 
Instance details

Defined in Language.Github.Actions.Service.Id

type Rep ServiceId = D1 ('MetaData "ServiceId" "Language.Github.Actions.Service.Id" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'True) (C1 ('MetaCons "ServiceId" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)))