github-actions-0.1.1.0: Github Actions
Copyright(c) 2025 Bellroy Pty Ltd
LicenseBSD-3-Clause
MaintainerBellroy Tech Team <haskell@bellroy.com>
Safe HaskellNone
LanguageHaskell2010

Language.Github.Actions.Step.Id

Description

This module provides the StepId type for uniquely identifying steps within GitHub Actions jobs.

Step IDs are used to reference step outputs from later steps in the same job or from other jobs. They must be unique within a job and follow specific naming conventions.

For more information about GitHub Actions step IDs, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#jobsjob_idstepsid

Synopsis

Documentation

newtype StepId Source #

A unique identifier for a step within a GitHub Actions job.

Step IDs are used to: * Reference step outputs from later steps using steps.step_id.outputs.output_name * Reference step outcomes using steps.step_id.outcome or steps.step_id.conclusion * Create dependencies between steps (though steps run sequentially by default)

Step IDs must be unique within a job and should follow these conventions: * Start with a letter or underscore * Contain only alphanumeric characters, hyphens, and underscores * Be descriptive of the step's purpose

Example usage:

import Language.Github.Actions.Step.Id

-- Simple step IDs
checkoutStepId :: StepId
checkoutStepId = StepId "checkout"

buildStepId :: StepId
buildStepId = StepId "build"

-- More descriptive step IDs
uploadArtifactsStepId :: StepId
uploadArtifactsStepId = StepId "upload-build-artifacts"

For more details, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#jobsjob_idstepsid

Constructors

StepId Text 

Instances

Instances details
FromJSON StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

FromJSONKey StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

ToJSON StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

ToJSONKey StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

Generic StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

Associated Types

type Rep StepId 
Instance details

Defined in Language.Github.Actions.Step.Id

type Rep StepId = D1 ('MetaData "StepId" "Language.Github.Actions.Step.Id" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'True) (C1 ('MetaCons "StepId" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)))

Methods

from :: StepId -> Rep StepId x #

to :: Rep StepId x -> StepId #

Show StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

Eq StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

Methods

(==) :: StepId -> StepId -> Bool #

(/=) :: StepId -> StepId -> Bool #

Ord StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

type Rep StepId Source # 
Instance details

Defined in Language.Github.Actions.Step.Id

type Rep StepId = D1 ('MetaData "StepId" "Language.Github.Actions.Step.Id" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'True) (C1 ('MetaCons "StepId" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)))