github-actions-0.1.1.0: Github Actions
Copyright(c) 2025 Bellroy Pty Ltd
LicenseBSD-3-Clause
MaintainerBellroy Tech Team <haskell@bellroy.com>
Safe HaskellNone
LanguageHaskell2010

Language.Github.Actions.UnstructuredMap

Description

This module provides the UnstructuredMap type for representing a map of values that can be strings, numbers, or booleans in GitHub Actions YAML files.

GitHub Actions allows flexible typing in many contexts: * retention-days: 1 (number) * retention-days: "1" (string) * should-retain: false (boolean)

This type preserves the original YAML type during round-trip parsing, ensuring that numeric values remain numeric and strings remain strings.

Synopsis

Documentation

data UnstructuredValue Source #

A map that can have values of string, number, or boolean.

This type is designed to handle the flexible typing that GitHub Actions allows in YAML files.

The type preserves the original format during round-trip serialization, so numeric inputs remain numeric in the output YAML.

Instances

Instances details
FromJSON UnstructuredValue Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

ToJSON UnstructuredValue Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Generic UnstructuredValue Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Associated Types

type Rep UnstructuredValue 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

type Rep UnstructuredValue = D1 ('MetaData "UnstructuredValue" "Language.Github.Actions.UnstructuredMap" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'False) (C1 ('MetaCons "UnstructuredValueString" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)) :+: (C1 ('MetaCons "UnstructuredValueNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double)) :+: C1 ('MetaCons "UnstructuredValueBool" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Bool))))
Show UnstructuredValue Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Eq UnstructuredValue Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Ord UnstructuredValue Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

type Rep UnstructuredValue Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

type Rep UnstructuredValue = D1 ('MetaData "UnstructuredValue" "Language.Github.Actions.UnstructuredMap" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'False) (C1 ('MetaCons "UnstructuredValueString" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)) :+: (C1 ('MetaCons "UnstructuredValueNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double)) :+: C1 ('MetaCons "UnstructuredValueBool" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Bool))))

newtype UnstructuredMap Source #

Instances

Instances details
FromJSON UnstructuredMap Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

ToJSON UnstructuredMap Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Generic UnstructuredMap Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Associated Types

type Rep UnstructuredMap 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

type Rep UnstructuredMap = D1 ('MetaData "UnstructuredMap" "Language.Github.Actions.UnstructuredMap" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'True) (C1 ('MetaCons "UnstructuredMap" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Map Text UnstructuredValue))))
Show UnstructuredMap Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Eq UnstructuredMap Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

Ord UnstructuredMap Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

type Rep UnstructuredMap Source # 
Instance details

Defined in Language.Github.Actions.UnstructuredMap

type Rep UnstructuredMap = D1 ('MetaData "UnstructuredMap" "Language.Github.Actions.UnstructuredMap" "github-actions-0.1.1.0-BjHhRMO6iQ17qdsNXwhDab" 'True) (C1 ('MetaCons "UnstructuredMap" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Map Text UnstructuredValue))))