| Copyright | (c) 2025 Bellroy Pty Ltd |
|---|---|
| License | BSD-3-Clause |
| Maintainer | Bellroy Tech Team <haskell@bellroy.com> |
| Safe Haskell | None |
| Language | Haskell2010 |
Language.Github.Actions.Concurrency
Description
This module provides the Concurrency type for controlling concurrent execution
of GitHub Actions workflows and jobs.
Concurrency settings allow you to control how many workflow runs or job executions can happen simultaneously.
For more information about GitHub Actions concurrency, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#concurrency
Synopsis
- data Concurrency = Concurrency {}
- gen :: MonadGen m => m Concurrency
Documentation
data Concurrency Source #
Concurrency settings for workflows and jobs.
Concurrency allows you to control whether multiple workflow runs or job executions can happen simultaneously. This is useful for preventing conflicts when deploying or when you want to ensure only one workflow processes a particular resource at a time.
Example usage:
import Language.Github.Actions.Concurrency
-- Only allow one deployment per branch
deploymentConcurrency :: Concurrency
deploymentConcurrency = Concurrency
{ group = Just "${{ github.ref }}"
, cancelInProgress = Just True
}
For more details, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#concurrency
Constructors
| Concurrency | |
Instances
gen :: MonadGen m => m Concurrency Source #