| Copyright | (c) 2025 Bellroy Pty Ltd |
|---|---|
| License | BSD-3-Clause |
| Maintainer | Bellroy Tech Team <haskell@bellroy.com> |
| Safe Haskell | None |
| Language | Haskell2010 |
Language.Github.Actions.Service.Id
Description
This module provides the ServiceId type for uniquely identifying service
containers within GitHub Actions jobs.
Service IDs are used to reference service containers from job steps via hostname. They must be unique within a job and follow specific naming conventions.
For more information about GitHub Actions service containers, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#jobsjob_idservices
Documentation
A unique identifier for a service container within a GitHub Actions job.
Service IDs are used to: * Reference the service container from job steps using the service ID as hostname * Configure service-specific settings like ports, environment variables, and health checks * Identify services in workflow run logs and container networks
Service IDs must be unique within a job and should follow these conventions: * Start with a letter or underscore * Contain only alphanumeric characters, hyphens, and underscores * Be descriptive of the service's purpose
Example usage:
import Language.Github.Actions.Service.Id -- Database service IDs postgresServiceId :: ServiceId postgresServiceId = ServiceId "postgres" redisServiceId :: ServiceId redisServiceId = ServiceId "redis" -- More descriptive service IDs testDatabaseServiceId :: ServiceId testDatabaseServiceId = ServiceId "test-database"
For more details, see: https://docs.github.com/en/actions/writing-workflows/workflow-syntax-for-github-actions#jobsjob_idservices
Instances
| FromJSON ServiceId Source # | |||||
Defined in Language.Github.Actions.Service.Id | |||||
| FromJSONKey ServiceId Source # | |||||
Defined in Language.Github.Actions.Service.Id Methods | |||||
| ToJSON ServiceId Source # | |||||
| ToJSONKey ServiceId Source # | |||||
Defined in Language.Github.Actions.Service.Id | |||||
| Generic ServiceId Source # | |||||
Defined in Language.Github.Actions.Service.Id Associated Types
| |||||
| Show ServiceId Source # | |||||
| Eq ServiceId Source # | |||||
| Ord ServiceId Source # | |||||
Defined in Language.Github.Actions.Service.Id | |||||
| type Rep ServiceId Source # | |||||
Defined in Language.Github.Actions.Service.Id | |||||